@@ -5,7 +5,6 @@
 # SPDX-FileCopyrightText: 2024 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from typing import Set
 
 from univention.management.console.modules.setup.netconf.common import Executable
 
@@ -31,17 +30,17 @@ class PhaseKernelModules(Executable):
         self.set_configured_modules(modules)
         self.load_modules(new_modules)
 
-    def get_configured_modules(self) -> Set[str]:
+    def get_configured_modules(self) -> set[str]:
         value = self.changeset.ucr.get(self.variable_name, "")
         modules = set(value.split(self.variable_separator))
         modules.discard("")
         return modules
 
-    def clean_known_modules(self, modules: Set[str]) -> None:
+    def clean_known_modules(self, modules: set[str]) -> None:
         for module, _option in self.module_option:
             modules.discard(module)
 
-    def scan_required_modules(self) -> Set[str]:
+    def scan_required_modules(self) -> set[str]:
         modules = set()
         for _name, iface in self.changeset.new_interfaces.all_interfaces:
             for iface_option in iface.options:
@@ -50,12 +49,12 @@ class PhaseKernelModules(Executable):
                         modules.add(module)
         return modules
 
-    def set_configured_modules(self, modules: Set[str]) -> None:
+    def set_configured_modules(self, modules: set[str]) -> None:
         value = self.variable_separator.join(sorted(modules)) or None
         self.logger.info("Updating '%s'='%s'...", self.variable_name, value)
         self.changeset.ucr_changes[self.variable_name] = value
 
-    def load_modules(self, modules: Set[str]) -> None:
+    def load_modules(self, modules: set[str]) -> None:
         if modules:
-            cmd = [self.executable] + list(modules)
+            cmd = [self.executable, *list(modules)]
             self.call(cmd)
