@@ -16,12 +16,12 @@ class PhaseResolvConv(Dhcp):
     priority = 75
 
     def check(self) -> None:
-        super(PhaseResolvConv, self).check()
+        super().check()
         if self.new_dhcps:
             raise SkipPhase("Still using DHCP")
 
     def post(self) -> None:
-        super(PhaseResolvConv, self).post()
+        super().post()
         self.logger.info("Committing /etc/resolv.conf...")
         if not self.changeset.no_act:
             handler_commit(["/etc/resolv.conf"])
