@@ -8,15 +8,15 @@
 import os
 import re
 from ipaddress import IPv4Interface
-from typing import Dict, Match
+from re import Match
 
 from univention.management.console.modules.setup.netconf import SkipPhase
 from univention.management.console.modules.setup.netconf.common import AddressMap
 
 
-class Mapping(object):
+class Mapping:
 
-    def __init__(self, ipv4_changes: Dict[IPv4Interface, IPv4Interface]) -> None:
+    def __init__(self, ipv4_changes: dict[IPv4Interface, IPv4Interface]) -> None:
         self.mapping = {
             str(old_ip.ip): str(new_ip.ip)
             for (old_ip, new_ip) in ipv4_changes.items()
@@ -47,7 +47,7 @@ class PhaseRewritePxe(AddressMap):
     dirname = "/var/lib/univention-client-boot/pxelinux.cfg"
 
     def check(self) -> None:
-        super(PhaseRewritePxe, self).check()
+        super().check()
         if not os.path.exists(self.dirname):
             raise SkipPhase("No '%s'" % (self.dirname,))
         if not any(self.ipv4_changes().values()):
