@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2011-2023 Univention GmbH
+# Copyright 2011-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -131,13 +131,17 @@ hostname=$(get_profile_var "hostname")
 # set domainame
 domainname=$(get_profile_var "domainname")
 [ -n "$domainname" ] && univention-config-registry set domainname="$domainname"
-# set ldap/basee
+# set ldap/base
 ldap_base=$(get_profile_var "ldap/base")
 [ -n "$ldap_base" ] && univention-config-registry set ldap/base="$ldap_base"
 # set windows domain
 windows_domain=$(get_profile_var "windows/domain")
 [ -n "$windows_domain" ] && univention-config-registry set windows/domain="$windows_domain"
 
+# restart udm to be sure the new settings apply
+. /usr/share/univention-lib/base.sh
+stop_udm_cli_server
+
 eval "$(univention-config-registry shell)"
 
 # The ldap server join script must create the Administrator account
@@ -332,6 +336,7 @@ ucr commit \
 
 # Restart NSCD
 service restart nscd
+service restart sssd
 
 # Start atd as the appliance cleanup script is started as at job
 service start atd
